Returns a list of dataset tags available on data.cdc.gov.
Use these tag names with cdc_datasets_tag().
See also
cdc_datasets_tag() to find datasets with a specific tag.
Returns a list of dataset tags available on data.cdc.gov.
Use these tag names with cdc_datasets_tag().
cdc_datasets_tag() to find datasets with a specific tag.